@@ -148,7 +148,11 @@ class StreamDecodeIteratorSync(ty.Generic[T_co]):
 	def close(self) -> None:
 		# Clean up any open iterators first
 		if self._response_iter is not None:
-			self._response_iter.close()
+			try:
+				self._response_iter.close()
+			except:
+				pass
+		
 		if self._parser_iter is not None:
 			self._parser_iter.close()
 		self._response_iter = None
@@ -429,7 +433,7 @@ class ClientSyncBase(ty.Generic[S], metaclass=abc.ABCMeta):
 		self._session = self._make_session()
 	
 	def close_session(self) -> None:
-		"""Close a session opened by
+		"""close a session opened by
 		:meth:`~ipfshttpclient.http.HTTPClient.open_session`.
 		
 		If there is no session currently open (ie: it was already closed), then
